==> CGAL-5.6.1-doc_html.tar.xz: doc_html/Partition_2/group__PkgPartition2Ref.js <==
var group__PkgPartition2Ref =
[
    [ "Concepts", "group__PkgPartition2Concepts.html", "group__PkgPartition2Concepts" ],
    [ "Function Object Concepts", "group__PkgPartition2FunctionObjectConcepts.html", "group__PkgPartition2FunctionObjectConcepts" ],
    [ "Function Object Classes", "group__PkgPartition2FunctionObjectClasses.html", "group__PkgPartition2FunctionObjectClasses" ],
    [ "Partition_is_valid_traits_2", "classCGAL_1_1Partition__is__valid__traits__2.html", [
      [ "Is_valid", "classCGAL_1_1Partition__is__valid__traits__2.html#a9947aa904c7706030e4055b4bab0262f", null ],
      [ "Left_turn_2", "classCGAL_1_1Partition__is__valid__traits__2.html#acc50293c55f26ad7e01d181891e93f64", null ],
      [ "Less_xy_2", "classCGAL_1_1Partition__is__valid__traits__2.html#a49c425ef478cfcc40b87f82d7b67c1ee", null ],
      [ "Orientation_2", "classCGAL_1_1Partition__is__valid__traits__2.html#a2c8a8e47314f54708796410c1c153cbb", null ],
      [ "Point_2", "classCGAL_1_1Partition__is__valid__traits__2.html#acb47b6a47154360476dc92a1845399d8", null ],
      [ "Polygon_2", "classCGAL_1_1Partition__is__valid__traits__2.html#ab282e350f2b15cc34aeb1ffbb1fa8877", null ],
      [ "is_valid_object", "classCGAL_1_1Partition__is__valid__traits__2.html#a65083fa4372ad4ff27e6d9c7816ad959", null ]
    ] ],
    [ "Partition_traits_2", "classCGAL_1_1Partition__traits__2.html", [
      [ "Are_strictly_ordered_along_line_2", "classCGAL_1_1Partition__traits__2.html#a6afd2a09cc07ba9b3ff952b9051f6255", null ],
      [ "Collinear_are_ordered_along_line_2", "classCGAL_1_1Partition__traits__2.html#a784e270a72e0ddaedacc9885a53daff0", null ],
      [ "Compare_x_2", "classCGAL_1_1Partition__traits__2.html#a5c99e6ee896b193593b080d4549c32e7", null ],
      [ "Compare_y_2", "classCGAL_1_1Partition__traits__2.html#a3f5da2a461d3412b9157bf3519c2bc70", null ],
      [ "Container", "classCGAL_1_1Partition__traits__2.html#a720042f5234c75108fa18cb6c2953595", null ],
      [ "FT", "classCGAL_1_1Partition__traits__2.html#a3c937369395cd2351859c605c5e4224b", null ],
      [ "Is_convex_2", "classCGAL_1_1Partition__traits__2.html#ae8f0128d85cdf1f7c626d40a1035eae3", null ],
      [ "Is_y_monotone_2", "classCGAL_1_1Partition__traits__2.html#a2639dd2a1a2ff9ba659ac801c2162e51", null ],
      [ "Left_turn_2", "classCGAL_1_1Partition__traits__2.html#aadedd6c792622a1a1b5c85404a0936b4", null ],
      [ "Less_xy_2", "classCGAL_1_1Partition__traits__2.html#a6db5ff574c0f651be8fa05a503ffb5f0", null ],
      [ "Less_yx_2", "classCGAL_1_1Partition__traits__2.html#a44d447c07a70091a74a752b0748225af", null ],
      [ "Orientation_2", "classCGAL_1_1Partition__traits__2.html#afc678fcb6c7bfc09af0af529240a627a", null ],
      [ "Point_2", "classCGAL_1_1Partition__traits__2.html#a62c198d9da3e45f8bcbbcd0176289d82", null ],
      [ "Polygon_2", "classCGAL_1_1Partition__traits__2.html#afbc2a23b317bc6565eaaf70d741ade1c", null ],
      [ "Self", "classCGAL_1_1Partition__traits__2.html#a2788c14dd1a67f19c3cf5c7fadd055b5", null ],
      [ "Partition_traits_2", "classCGAL_1_1Partition__traits__2.html#a2d64b25231a60f075e3f831c3f74afed", null ],
      [ "Partition_traits_2", "classCGAL_1_1Partition__traits__2.html#aeb5449be3bc779f353b89d66bf4674a7", null ],
      [ "Partition_traits_2", "classCGAL_1_1Partition__traits__2.html#a7ebdec60b6c6f720c2b60efc3c0ee4ba", null ],
      [ "Partition_traits_2", "classCGAL_1_1Partition__traits__2.html#aca93d6d55134161a2aab5d0980121787", null ],
      [ "pred_object_type_object", "classCGAL_1_1Partition__traits__2.html#abd68ffdead6be606b5f7a6191fd95157", null ]
    ] ],
    [ "approx_convex_partition_2", "group__PkgPartition2Ref.html#gab9cf8c2b097fd562da09dd23d0c74edf", null ],
    [ "convex_partition_is_valid_2", "group__PkgPartition2Ref.html#ga9d234240af69b14694923824fc8fca12", null ],
    [ "greene_approx_convex_partition_2", "group__PkgPartition2Ref.html#ga68139e1ee98dffa8f72cb295881f4647", null ],
    [ "is_y_monotone_2", "group__PkgPartition2Ref.html#gae795b8beb8626322c448706e20a8ac9b", null ],
    [ "optimal_convex_partition_2", "group__PkgPartition2Ref.html#ga3ca9fb1f363f9f792bfbbeca65ad5cc5", null ],
    [ "partition_is_valid_2", "group__PkgPartition2Ref.html#gaa4c7b5c06a64608fca50ddb2af49d498", null ],
    [ "y_monotone_partition_2", "group__PkgPartition2Ref.html#ga35cdd9f604522c2ce4ca97d928a41f38", null ],
    [ "y_monotone_partition_is_valid_2", "group__PkgPartition2Ref.html#gaaf27de7c6e366901d744e6bc32e2a8a1", null ]
];

==> CGAL-6.1-doc_html.tar.xz: doc_html/Partition_2/group__PkgPartition2Ref.js <==
var group__PkgPartition2Ref =
[
    [ "Concepts", "group__PkgPartition2Concepts.html", "group__PkgPartition2Concepts" ],
    [ "Function Object Concepts", "group__PkgPartition2FunctionObjectConcepts.html", "group__PkgPartition2FunctionObjectConcepts" ],
    [ "Function Object Classes", "group__PkgPartition2FunctionObjectClasses.html", "group__PkgPartition2FunctionObjectClasses" ],
    [ "CGAL::Partition_is_valid_traits_2< Traits, PolygonIsValid >", "classCGAL_1_1Partition__is__valid__traits__2.html", [
      [ "Is_valid", "classCGAL_1_1Partition__is__valid__traits__2.html#a9947aa904c7706030e4055b4bab0262f", null ],
      [ "Left_turn_2", "classCGAL_1_1Partition__is__valid__traits__2.html#acc50293c55f26ad7e01d181891e93f64", null ],
      [ "Less_xy_2", "classCGAL_1_1Partition__is__valid__traits__2.html#a49c425ef478cfcc40b87f82d7b67c1ee", null ],
      [ "Orientation_2", "classCGAL_1_1Partition__is__valid__traits__2.html#a2c8a8e47314f54708796410c1c153cbb", null ],
      [ "Point_2", "classCGAL_1_1Partition__is__valid__traits__2.html#acb47b6a47154360476dc92a1845399d8", null ],
      [ "Polygon_2", "classCGAL_1_1Partition__is__valid__traits__2.html#ab282e350f2b15cc34aeb1ffbb1fa8877", null ],
      [ "is_valid_object", "classCGAL_1_1Partition__is__valid__traits__2.html#a65083fa4372ad4ff27e6d9c7816ad959", null ]
    ] ],
    [ "CGAL::Partition_traits_2< R, PointPropertyMap >", "classCGAL_1_1Partition__traits__2.html", [
      [ "Are_strictly_ordered_along_line_2", "classCGAL_1_1Partition__traits__2.html#a6afd2a09cc07ba9b3ff952b9051f6255", null ],
      [ "Collinear_are_ordered_along_line_2", "classCGAL_1_1Partition__traits__2.html#a784e270a72e0ddaedacc9885a53daff0", null ],
      [ "Compare_x_2", "classCGAL_1_1Partition__traits__2.html#a5c99e6ee896b193593b080d4549c32e7", null ],
      [ "Compare_y_2", "classCGAL_1_1Partition__traits__2.html#a3f5da2a461d3412b9157bf3519c2bc70", null ],
      [ "Container", "classCGAL_1_1Partition__traits__2.html#a720042f5234c75108fa18cb6c2953595", null ],
      [ "FT", "classCGAL_1_1Partition__traits__2.html#a3c937369395cd2351859c605c5e4224b", null ],
      [ "Is_convex_2", "classCGAL_1_1Partition__traits__2.html#ae8f0128d85cdf1f7c626d40a1035eae3", null ],
      [ "Is_y_monotone_2", "classCGAL_1_1Partition__traits__2.html#a2639dd2a1a2ff9ba659ac801c2162e51", null ],
      [ "Left_turn_2", "classCGAL_1_1Partition__traits__2.html#aadedd6c792622a1a1b5c85404a0936b4", null ],
      [ "Less_xy_2", "classCGAL_1_1Partition__traits__2.html#a6db5ff574c0f651be8fa05a503ffb5f0", null ],
      [ "Less_yx_2", "classCGAL_1_1Partition__traits__2.html#a44d447c07a70091a74a752b0748225af", null ],
      [ "Orientation_2", "classCGAL_1_1Partition__traits__2.html#afc678fcb6c7bfc09af0af529240a627a", null ],
      [ "Point_2", "classCGAL_1_1Partition__traits__2.html#a62c198d9da3e45f8bcbbcd0176289d82", null ],
      [ "Polygon_2", "classCGAL_1_1Partition__traits__2.html#afbc2a23b317bc6565eaaf70d741ade1c", null ],
      [ "Self", "classCGAL_1_1Partition__traits__2.html#a2788c14dd1a67f19c3cf5c7fadd055b5", null ],
      [ "Partition_traits_2", "classCGAL_1_1Partition__traits__2.html#a2d64b25231a60f075e3f831c3f74afed", null ],
      [ "Partition_traits_2", "classCGAL_1_1Partition__traits__2.html#aeb5449be3bc779f353b89d66bf4674a7", null ],
      [ "Partition_traits_2", "classCGAL_1_1Partition__traits__2.html#a7ebdec60b6c6f720c2b60efc3c0ee4ba", null ],
      [ "Partition_traits_2", "classCGAL_1_1Partition__traits__2.html#aca93d6d55134161a2aab5d0980121787", null ],
      [ "pred_object_type_object", "classCGAL_1_1Partition__traits__2.html#abd68ffdead6be606b5f7a6191fd95157", null ]
    ] ],
    [ "CGAL::approx_convex_partition_2", "group__PkgPartition2Ref.html#gab9cf8c2b097fd562da09dd23d0c74edf", null ],
    [ "CGAL::convex_partition_is_valid_2", "group__PkgPartition2Ref.html#ga9d234240af69b14694923824fc8fca12", null ],
    [ "CGAL::greene_approx_convex_partition_2", "group__PkgPartition2Ref.html#ga68139e1ee98dffa8f72cb295881f4647", null ],
    [ "CGAL::is_y_monotone_2", "group__PkgPartition2Ref.html#gae795b8beb8626322c448706e20a8ac9b", null ],
    [ "CGAL::optimal_convex_partition_2", "group__PkgPartition2Ref.html#ga3ca9fb1f363f9f792bfbbeca65ad5cc5", null ],
    [ "CGAL::partition_is_valid_2", "group__PkgPartition2Ref.html#gaa4c7b5c06a64608fca50ddb2af49d498", null ],
    [ "CGAL::y_monotone_partition_2", "group__PkgPartition2Ref.html#ga35cdd9f604522c2ce4ca97d928a41f38", null ],
    [ "CGAL::y_monotone_partition_is_valid_2", "group__PkgPartition2Ref.html#gaaf27de7c6e366901d744e6bc32e2a8a1", null ]
];
